==> kubernetes-model-autoscaling-6.6.2-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2/PodsMetricSourceFluent.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface PodsMetricSourceFluent<A extends PodsMetricSourceFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildMetric instead.
   * @return The buildable object.
   */
  @Deprecated
  public MetricIdentifier getMetric();
  public MetricIdentifier buildMetric();
  public A withMetric(MetricIdentifier metric);
  public Boolean hasMetric();
  public PodsMetricSourceFluent.MetricNested<A> withNewMetric();
  public PodsMetricSourceFluent.MetricNested<A> withNewMetricLike(MetricIdentifier item);
  public PodsMetricSourceFluent.MetricNested<A> editMetric();
  public PodsMetricSourceFluent.MetricNested<A> editOrNewMetric();
  public PodsMetricSourceFluent.MetricNested<A> editOrNewMetricLike(MetricIdentifier item);
  
  /**
   * This method has been deprecated, please use method buildTarget instead.
   * @return The buildable object.
   */
  @Deprecated
  public MetricTarget getTarget();
  public MetricTarget buildTarget();
  public A withTarget(MetricTarget target);
  public Boolean hasTarget();
  public PodsMetricSourceFluent.TargetNested<A> withNewTarget();
  public PodsMetricSourceFluent.TargetNested<A> withNewTargetLike(MetricTarget item);
  public PodsMetricSourceFluent.TargetNested<A> editTarget();
  public PodsMetricSourceFluent.TargetNested<A> editOrNewTarget();
  public PodsMetricSourceFluent.TargetNested<A> editOrNewTargetLike(MetricTarget item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MetricNested<N> extends Nested<N>,MetricIdentifierFluent<PodsMetricSourceFluent.MetricNested<N>>{
    public N and();
    public N endMetric();
    
  }
  public interface TargetNested<N> extends Nested<N>,MetricTargetFluent<PodsMetricSourceFluent.TargetNested<N>>{
    public N and();
    public N endTarget();
    
  }
  
}

==> kubernetes-model-autoscaling-6.7.1-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2/PodsMetricSourceFluent.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface PodsMetricSourceFluent<A extends PodsMetricSourceFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildMetric instead.
   * @return The buildable object.
   */
  @Deprecated
  public MetricIdentifier getMetric();
  public MetricIdentifier buildMetric();
  public A withMetric(MetricIdentifier metric);
  public Boolean hasMetric();
  public PodsMetricSourceFluent.MetricNested<A> withNewMetric();
  public PodsMetricSourceFluent.MetricNested<A> withNewMetricLike(MetricIdentifier item);
  public PodsMetricSourceFluent.MetricNested<A> editMetric();
  public PodsMetricSourceFluent.MetricNested<A> editOrNewMetric();
  public PodsMetricSourceFluent.MetricNested<A> editOrNewMetricLike(MetricIdentifier item);
  
  /**
   * This method has been deprecated, please use method buildTarget instead.
   * @return The buildable object.
   */
  @Deprecated
  public MetricTarget getTarget();
  public MetricTarget buildTarget();
  public A withTarget(MetricTarget target);
  public Boolean hasTarget();
  public PodsMetricSourceFluent.TargetNested<A> withNewTarget();
  public PodsMetricSourceFluent.TargetNested<A> withNewTargetLike(MetricTarget item);
  public PodsMetricSourceFluent.TargetNested<A> editTarget();
  public PodsMetricSourceFluent.TargetNested<A> editOrNewTarget();
  public PodsMetricSourceFluent.TargetNested<A> editOrNewTargetLike(MetricTarget item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MetricNested<N> extends Nested<N>,MetricIdentifierFluent<PodsMetricSourceFluent.MetricNested<N>>{
    public N and();
    public N endMetric();
    
  }
  public interface TargetNested<N> extends Nested<N>,MetricTargetFluent<PodsMetricSourceFluent.TargetNested<N>>{
    public N and();
    public N endTarget();
    
  }
  
}
